@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2010, 2013, 2014, 2015, 2016, 2017 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include "window.h"
 
 #include "board.h"
+#include "locale_dialog.h"
 
 #include <QApplication>
 #include <QMenuBar>
@@ -29,22 +30,25 @@
 /*****************************************************************************/
 
 Window::Window() {
-	setWindowIcon(QIcon(":/hexalate.png"));
-	setWindowTitle(tr("Hexalate"));
-
 	// Create game board
 	Board* board = new Board(this);
 	setCentralWidget(board);
 
 	// Create menus
 	QMenu* menu = menuBar()->addMenu(tr("&Game"));
-	menu->addAction(tr("&New"), board, SLOT(newGame()), tr("Ctrl+N"));
+	menu->addAction(tr("&New"), board, SLOT(newGame()), QKeySequence::New);
 	menu->addSeparator();
-	menu->addAction(tr("&Quit"), qApp, SLOT(quit()), tr("Ctrl+Q"));
+	QAction* action = menu->addAction(tr("&Quit"), qApp, SLOT(quit()), QKeySequence::Quit);
+	action->setMenuRole(QAction::QuitRole);
+
+	menu = menuBar()->addMenu(tr("&Settings"));
+	menu->addAction(tr("Application &Language..."), this, SLOT(setLocale()));
 
 	menu = menuBar()->addMenu(tr("&Help"));
-	menu->addAction(tr("&About"), this, SLOT(about()));
-	menu->addAction(tr("About &Qt"), qApp, SLOT(aboutQt()));
+	action = menu->addAction(tr("&About"), this, SLOT(about()));
+	action->setMenuRole(QAction::AboutRole);
+	action = menu->addAction(tr("About &Qt"), qApp, SLOT(aboutQt()));
+	action->setMenuRole(QAction::AboutQtRole);
 
 	// Restore size and position
 	restoreGeometry(QSettings().value("Geometry").toByteArray());
@@ -59,8 +63,20 @@ void Window::closeEvent(QCloseEvent* event) {
 
 /*****************************************************************************/
 
+void Window::setLocale() {
+	LocaleDialog dialog(this);
+	dialog.exec();
+}
+
+/*****************************************************************************/
+
 void Window::about() {
-	QMessageBox::about(this, tr("About Hexalate"), tr("<center><big><b>Hexalate %1</b></big><br/>A color matching game<br/><small>Copyright &copy; 2009 Graeme Gott</small></center>").arg(qApp->applicationVersion()));
+	QMessageBox::about(this, tr("About Hexalate"), QString("<p align='center'><big><b>%1 %2</b></big><br/>%3<br/><small>%4<br/>%5</small></p>")
+		.arg(tr("Hexalate"), QCoreApplication::applicationVersion(),
+			tr("A color matching game"),
+			tr("Copyright &copy; 2009-%1 Graeme Gott").arg("2017"),
+			tr("Released under the <a href=%1>GPL 3</a> license").arg("\"http://www.gnu.org/licenses/gpl.html\""))
+	);
 }
 
 /*****************************************************************************/
